@@ -141,7 +141,7 @@ QByteArray LXQt::Wallet::kwallet::readValue(const QString &key)
 
     m_kwallet->readPassword(key, value);
 
-    return value.toLatin1();
+    return value.toUtf8();
 }
 
 QVector<std::pair<QString, QByteArray>> LXQt::Wallet::kwallet::readAllKeyValues(void)
@@ -160,7 +160,7 @@ QVector<std::pair<QString, QByteArray>> LXQt::Wallet::kwallet::readAllKeyValues(
 
         m_kwallet->readPassword(e, value);
 
-	p.append({ e, value.toLatin1() });
+	p.append({ e, value.toUtf8() });
     }
 
     return p;
