@@ -38,6 +38,8 @@ configOptions::configOptions( QWidget * parent,
 
 	this->setFixedSize( this->window()->size() ) ;
 
+	this->installEventFilter( this ) ;
+
 	m_ui->tabWidget->setCurrentIndex( 0 ) ;
 
 	m_ui->pbMountPointPrefix->setIcon( QIcon( ":/folder.png" ) ) ;
@@ -96,12 +98,15 @@ configOptions::configOptions( QWidget * parent,
 
 		if( !e.isEmpty() ){
 
-			m_ui->lineEditMountPointPrefix->setText( e ) ;
-
 			if( utility::platformIsWindows() ){
 
 				m_settings.setWindowsExecutableSearchPath( e ) ;
+				auto m = m_settings.windowsExecutableSearchPath() ;
+
+				m_ui->lineEditMountPointPrefix->setText( m ) ;
 			}else{
+				m_ui->lineEditMountPointPrefix->setText( e ) ;
+
 				m_settings.setDefaultMountPointPrefix( e ) ;
 			}
 		}
@@ -312,13 +317,6 @@ void configOptions::HideUI()
 		m_settings.runCommandOnIntervalTime( 10 ) ;
 	}
 
-	if( utility::platformIsWindows() ){
-
-		m_settings.setWindowsExecutableSearchPath( m_ui->lineEditMountPointPrefix->text() ) ;
-	}else{
-		m_settings.setDefaultMountPointPrefix( m_ui->lineEditMountPointPrefix->text() ) ;
-	}
-
 	this->hide() ;
 }
 
@@ -327,3 +325,8 @@ void configOptions::closeEvent( QCloseEvent * e )
 	e->ignore() ;
 	this->HideUI() ;
 }
+
+bool configOptions::eventFilter( QObject * watched,QEvent * event )
+{
+	return utility::eventFilter( this,watched,event,[ this ](){ this->HideUI() ; } ) ;
+}
