@@ -148,23 +148,24 @@ void createBackendWIndow::save()
 	config[ "unMountCommand" ]              = emptyStringList ;
 	config[ "volumePropertiesCommands" ]    = emptyStringList ;
 	config[ "passwordFormat" ]              = "%{password}" ;
-	config[ "sshOptions" ]                  = "idmap=user,StrictHostKeyChecking=no" ;
+	config[ "defaultFavoritesMountOptions" ]    = "" ;
 	config[ "windowsInstallPathRegistryKey" ]   = "" ;
 	config[ "windowsInstallPathRegistryValue" ] = "" ;
 	config[ "windowsExecutableFolderPath" ]     = "" ;
 	config[ "displayName" ]                     = "" ;
+	config[ "sirikaliMinimumVersion" ]          = "" ;
 	config[ "windowsSupportsMountPointPaths" ]  = m_ui->cbSupportsMountPointPaths->isChecked() ;
-	config[ "windowsSuccessfullyMountedList" ]  = _addList( m_ui->lineEditSuccessfullyMountedText->text() ) ;
-	config[ "executableName" ]              = executable ;
-	config[ "configFileNames" ]             = _addList( configFileNames ) ;
-	config[ "fuseNames" ]                   = _addList( fusenames ) ;
-	config[ "names" ]                       = _addList( names ) ;
-	config[ "failedToMountTextList" ]       = _addList( m_ui->lineEditFailedToMountText->text() ) ;
+	config[ "configFileNames" ]                   = _addList( configFileNames ) ;
+	config[ "fuseNames" ]                         = _addList( fusenames ) ;
+	config[ "names" ]                             = _addList( names ) ;
+	config[ "stringsToCheckForFailedMount" ]      = _addList( m_ui->lineEditFailedToMountText->text() ) ;
+	config[ "stringsToCheckForSuccessfulMount" ]  = _addList( m_ui->lineEditSuccessfullyMountedText->text() ) ;
 	config[ "configFileArgument" ]          = m_ui->lineEditConfigFileArgument->text() ;
 	config[ "wrongPasswordText" ]           = password ;
 	config[ "wrongPasswordErrorCode" ]      = m_ui->lineEditWrongPasswordErrorCode->text() ;
 	config[ "requiresAPassword" ]           = m_ui->cbRequiresAPassword->isChecked() ;
 	config[ "autoMountsOnVolumeCreation" ]  = m_ui->cbAutoMountsOnVolumeCreation->isChecked() ;
+	config[ "executableName" ]              = executable ;
 	config[ "backendRequireMountPath" ]     = true ;
 	config[ "autorefreshOnMountUnMount" ]   = true ;
 	config[ "backendTimeout" ]              = 0 ;
