@@ -217,30 +217,6 @@ public:
 			int numberOfAttempts ;
 		} ;
 
-		struct exe_args{
-		        exe_args( QString e,QStringList s ) :
-			        exe( std::move( e ) ),args( std::move( s ) )
-			{
-			}
-			exe_args()
-			{
-			}
-			QString exe ;
-			QStringList args ;
-		};
-
-		struct exe_args_const{
-			exe_args_const( const exe_args& e ) : exe( e.exe ),args( e.args )
-			{
-			}
-			exe_args_const( const QString& e,const QStringList& s ) :
-				exe( e ),args( s )
-			{
-			}
-			const QString& exe ;
-			const QStringList& args ;
-		};
-
 		class Wrapper{
 		public:
 			Wrapper( const engines::engine& e ) :
@@ -278,6 +254,8 @@ public:
 			success,
 			volumeCreatedSuccessfully,
 
+			fuserMountNotFound,
+
 			backendRequiresPassword,
 			badPassword,
 
@@ -312,6 +290,34 @@ public:
 			unknown
 		} ;
 
+		struct exe_args{
+			exe_args( QString e,QStringList s ) :
+				exe( std::move( e ) ),args( std::move( s ) )
+			{
+			}
+			exe_args()
+			{
+			}
+			exe_args( engines::engine::status e ) : error( e )
+			{
+			}
+			engines::engine::status error = engines::engine::status::success ;
+			QString exe ;
+			QStringList args ;
+		};
+
+		struct exe_args_const{
+			exe_args_const( const exe_args& e ) : exe( e.exe ),args( e.args )
+			{
+			}
+			exe_args_const( const QString& e,const QStringList& s ) :
+				exe( e ),args( s )
+			{
+			}
+			const QString& exe ;
+			const QStringList& args ;
+		};
+
 		class cmdStatus
 		{
 		public:
@@ -703,6 +709,8 @@ public:
 
 		virtual bool takesTooLongToUnlock() const ;
 
+		virtual void aboutToExit() const ;
+
 		virtual QByteArray prepareBackend() const ;
 
 		virtual engine::engine::status passAllRequirenments( const engines::engine::cmdArgsList& ) const ;
@@ -890,6 +898,7 @@ public:
 	volumeInfo::List mountInfo( const volumeInfo::List& ) const ;
 	QStringList enginesWithNoConfigFile() const ;
 	QStringList enginesWithConfigFile() const ;
+	void aboutToExit() const ;
 	const std::vector< engines::engine::Wrapper >& supportedEngines() const ;
 
 	class engineWithPaths{
